@@ -31,7 +31,7 @@ class DataClient:
         self.debug = debug
         self.token = os.environ["DC_TOKEN"] if "DC_TOKEN" in os.environ else token
 
-        self.get_bars = partial(self.history, data_type="bar", freq="BQS", use_cache=use_cache)
+        self.get_bars = partial(self.history, data_type="bar", freq="BMS", use_cache=use_cache)
         self.get_ticks = partial(self.history, data_type="tick", freq="12BH", use_cache=use_cache)
         self.get_dailys = partial(self.history, data_type="daily", freq="BAS", use_cache=use_cache)
 
@@ -61,7 +61,7 @@ class DataClient:
                     "start_date": datetime.strftime(date_split[index], "%Y%m%d%H%M%S"),
                     "end_date": datetime.strftime(date_split[index+1], "%Y%m%d%H%M%S"),
                 }
-                key = json.dumps(args, sort_keys=True)
+                key = "_".join(sorted(args.values(), reverse=True))
                 cache_file = os.path.join(gettempdir(), key)
                 cache_client = shelve.open(cache_file, writeback=True)
                 try:
@@ -95,8 +95,8 @@ if __name__ == "__main__":
     # 分钟
     bars = client.get_bars(
         "SHFE.rb@INDEX",
-        start_data=datetime(2020, 4, 6, 21, 0, 0),
-        end_date=datetime(2021, 6, 4, 15, 0, 0)
+        start_data=datetime(2020, 4, 6),
+        end_date=datetime(2021, 6, 4)
     )
     print(bars)
 
